gg_is_flutter library
Properties
- isFlutter → bool
-
Returns true if the current project is a flutter project
no setter
- testIsFlutter ↔ bool?
-
Use this variable to enforce a specific value for isFlutter in tests
getter/setter pair
Functions
-
isFlutterDir(
Directory dir) → bool - Returns true if the project in dir is a flutter project
-
testResetIsFlutter(
) → void - Reset the value of isFlutter to null for test purposes